{% load static %}
{% load i18n %}

<div class="afat-spinner d-none text-center">
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset="{% static "afat/images/ring-resize-white-36.svg" %}">
        <img src="{% static "afat/images/ring-resize-black-36.svg" %}" alt="{% translate 'Loading …' %}">
    </picture>
</div>
